@@ -87,7 +87,7 @@ class TableInfo:
         self._templates.append(template)
 
     def __repr__(self) -> str:
-        return f"<TableInfo fields={list(self.fields.keys())} friends={list(self.friends.keys())} templates={len(self._templates)}>"
+        return f"<TableInfo name={self.name} fields={list(self.fields.keys())} friends={list(self.friends.keys())} templates={len(self._templates)}>"
 
 
 class ParseContext:
@@ -120,7 +120,7 @@ class ParseContext:
             my_line_num = self.line_numbers.get(id(obj))
             if my_line_num and my_line_num != SHARED_OBJECT:
                 return my_line_num._asdict()
-        except KeyError:
+        except KeyError:  # pragma: no cover
             pass
 
         assert obj != self.current_parent_object  # check for no infinite loop
@@ -132,10 +132,6 @@ class ParseContext:
         self.current_parent_object = obj
         try:
             yield
-        except exc.DataGenError:
-            raise
-        except Exception as e:
-            raise exc.DataGenSyntaxError(str(e), **self.line_num()) from e
         finally:
             self.current_parent_object = _old_parsed_template
 
@@ -227,12 +223,9 @@ def parse_structured_value(name: str, field: Dict, context: ParseContext) -> Def
             func = getattr(plugin, name)
             rc = func(context, args)
             return rc
-        except AttributeError as e:
-            # check if this is a regular runtime function. If so,
-            # fall-through and handle it as if we had never
-            # tried to parse it as a macro plugin
-            if not hasattr(plugin, "Functions") and not hasattr(plugin.Functions, name):
-                raise e
+        except AttributeError:
+            # we'll try to find it a different way below
+            pass
 
     args = parse_structured_value_args(args, context)
     ret = StructuredValue(function_name, args, **context.line_num(field))
@@ -261,11 +254,10 @@ def parse_field_value(
             field[0],
             context,
         )
-    else:
-        raise exc.DataGenSyntaxError(
-            f"Unknown field {type(field)} type for {name}. Should be a string or 'object': \n {field} ",
-            **(context.line_num(field) or context.line_num()),
-        )
+    # should be unreachable. Every code path to here tests types
+    raise AssertionError(
+        f"Unknown field {type(field)} type for {name}. Should be a string or 'object': \n {field} "
+    )
 
 
 def parse_field(name: str, definition, context: ParseContext) -> FieldFactory:
@@ -279,11 +271,11 @@ def parse_field(name: str, definition, context: ParseContext) -> FieldFactory:
 
 def parse_fields(fields: Dict, context: ParseContext) -> List[FieldFactory]:
     with context.change_current_parent_object(fields):
-        if not isinstance(fields, dict):
-            raise exc.DataGenSyntaxError(
-                "Fields should be a dictionary (should not start with -) ",
-                **context.line_num(),
-            )
+        # Should be unreachable because parser checks first.
+        assert isinstance(
+            fields, dict
+        ), "Fields should be a dictionary (should not start with -) "
+
         return [
             parse_field(name, definition, context)
             for name, definition in fields.items()
@@ -411,16 +403,15 @@ def parse_object_template(yaml_sobj: Dict, context: ParseContext) -> ObjectTempl
             # but the use-case wasn't obvious so it was removed
             # after 9bc296a7df. If we get to 2023 without
             # finding a use-case we can delete this comment.
-            if isinstance(for_each_expr, dict):
-                sobj_def["for_each_expr"] = parse_for_each_variable_definition(
-                    for_each_expr, context
-                )
-            else:  # pragma: no cover
-                # this code should be unreachable due to checks earlier
-                raise exc.DataGenSyntaxError(
-                    "`for_each` must evaluate to a variable description",
-                    **context.line_num(),
-                )
+
+            # this type should have been checked earlier
+            assert isinstance(
+                for_each_expr, dict
+            ), "`for_each` must evaluate to a variable description"
+            sobj_def["for_each_expr"] = parse_for_each_variable_definition(
+                for_each_expr, context
+            )
+
         new_template = ObjectTemplate(**sobj_def)
         context.register_template(new_template)
         return new_template
@@ -640,7 +631,6 @@ def categorize_top_level_objects(data: List, context: ParseContext):
         if not isinstance(obj, dict):
             raise exc.DataGenSyntaxError(
                 f"Top level elements in a data generation template should all be dictionaries, not {obj}",
-                **context.line_num(data),
             )
         obj_category = None
         for declaration, category in collection_rules.items():
@@ -751,11 +741,17 @@ def build_update_recipe(
         raise exc.DataGenSyntaxError(error_message)
     template = statements[0]
     if not isinstance(template, ObjectTemplate):
-        raise exc.DataGenSyntaxError(error_message, **template.line_num())
+        raise exc.DataGenSyntaxError(
+            error_message,
+            filename=template.filename,
+            line_num=template.line_num,
+        )
 
     if template.count_expr:
         raise exc.DataGenSyntaxError(
-            "Update templates should have no 'count'", **template.line_num()
+            "Update templates should have no 'count'",
+            filename=template.filename,
+            line_num=template.line_num,
         )
 
     template.for_each_expr = ForEachVariableDefinition(
